@@ -1,4 +1,4 @@
-from slack.errors import SlackApiError
+from slack_sdk.errors import SlackApiError
 
 
 class BaseException(Exception):
@@ -13,6 +13,9 @@ class ArgumentError(CommandError):
     pass
 
 
+# Custom slack exceptions
+
+
 class ArchiveException(SlackApiError):
     pass
 
